==> smartgwtee-eval-12.0p.zip: com/smartgwt/logicalstructure/widgets/ScrollbarLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class ScrollbarLogicalStructure extends StretchImgLogicalStructure {
    public String allowThumbDownState;
    public String allowThumbOverState;
    public String autoEnable;
    public String btnSize;
    public StretchItem cornerImg;
    public String cornerSize;
    public String cornerSrc;
    public StretchItem endImg;
    public String endThumbOverlap;
    public String hSrc;
    public Canvas scrollTarget;
    public String showCorner;
    public String showTrackButtons;
    public String showTrackEnds;
    public String skinImgDir;
    public StretchItem startImg;
    public String startThumbOverlap;
    public String thumbInset;
    public String thumbMinSize;
    public String thumbOverlap;
    public String trackEndHeight;
    public StretchItem trackEndImg;
    public String trackEndWidth;
    public StretchItem trackImg;
    public StretchItem trackStartImg;
    public String vSrc;
}

==> smartgwtee-eval-12.1p.zip: com/smartgwt/logicalstructure/widgets/ScrollbarLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class ScrollbarLogicalStructure extends StretchImgLogicalStructure {
    public String allowThumbDownState;
    public String allowThumbOverState;
    public String autoEnable;
    public String btnSize;
    public StretchItem cornerImg;
    public String cornerSize;
    public String cornerSrc;
    public StretchItem endImg;
    public String endThumbOverlap;
    public String hSrc;
    public Canvas scrollTarget;
    public String showCorner;
    public String showTrackButtons;
    public String showTrackEnds;
    public String skinImgDir;
    public StretchItem startImg;
    public String startThumbOverlap;
    public String thumbInset;
    public String thumbMinSize;
    public String thumbOverlap;
    public String trackEndHeight;
    public StretchItem trackEndImg;
    public String trackEndWidth;
    public StretchItem trackImg;
    public StretchItem trackStartImg;
    public String vSrc;
}
